// Test to demonstrate Eclipse CDT's inability to parse class-nested enum classes.
// Build line: g++ -std=c++11 -Wall -Wextra -ggdb3 -Og -o accel accel.cpp

#include "accel.hpp"

enum class AccelLis2de12::RegAddr : uint8_t {
    //                OFS      Acc. Default
    STATUS_REG_AUX  = 0x07, // r    Output
    // Reserved     = 08-0B
    OUT_TEMP_L      = 0x0C, // r    Output
    OUT_TEMP_H      = 0x0D, // r    Output
    // Reserved     = 0E
    WHO_AM_I        = 0x0F, // r 0  0110011
    // Reserved     = 10-1D
    CTRL_REG0       = 0x1E, // rw   00010000
    TEMP_CFG_REG    = 0x1F, // rw   00000000
    CTRL_REG1       = 0x20, // rw   00000111
    CTRL_REG2       = 0x21, // rw   00000000
    CTRL_REG3       = 0x22, // rw   00000000
    CTRL_REG4       = 0x23, // rw   00000000
    CTRL_REG5       = 0x24, // rw   00000000
    CTRL_REG6       = 0x25, // rw   00000000
    REFERENCE       = 0x26, // rw   00000000
    DATACAPTURE     = 0x26, // rw   00000000
    STATUS_REG      = 0x27, // r    Output
    FIFO_READ_START = 0x28, // r    Output
    OUT_X_H         = 0x29, // r    Output
    // Reserved     = 2A
    OUT_Y_H         = 0x2B, // r    Output
    // Reserved     = 2C
    OUT_Z_H         = 0x2D, // r    Output
    FIFO_CTRL       = 0x2E, // rw   00000000
    FIFO_SRC        = 0x2F, // r    Output
    INT1_CFG        = 0x30, // rw   00000000
    INT1_SRC        = 0x31, // r    Output
    INT1_THS        = 0x32, // rw   00000000
    INT1_DUR        = 0x33, // rw   00000000
    INT2_CFG        = 0x34, // rw   00000000
    INT2_SRC        = 0x35, // r    Output
    INT2_THS        = 0x36, // rw   00000000
    INT2_DUR        = 0x37, // rw   00000000
    CLICK_CFG       = 0x38, // rw   00000000
    CLICK_SRC       = 0x39, // r    Output
    CLICK_THS       = 0x3A, // rw   00000000
    TIME_LIMIT      = 0x3B, // rw   00000000
    TIME_LATENCY    = 0x3C, // rw   00000000
    TIME_WINDOW     = 0x3D, // rw   00000000
    ACT_THS         = 0x3E, // rw   00000000
    ACT_DUR         = 0x3F, // rw   00000000
} RegAddr;

union CtrlReg1 {
    struct {
        uint8_t xen  : 1;
        uint8_t yen  : 1;
        uint8_t zen  : 1;
        uint8_t lpen : 1;
        uint8_t odr  : 4;
    } bit;
    uint8_t reg;
};

static CtrlReg1 ctrl_reg1{};

bool AccelLis2de12::rd_reg(RegAddr reg, void *val)
{
    if (reg == RegAddr::CTRL_REG1) {
        CtrlReg1 *typed_val = reinterpret_cast<CtrlReg1*>(val);
        typed_val->reg = ctrl_reg1.reg;
        return true;
    }

    return false;
}

bool AccelLis2de12::read_test()
{
    CtrlReg1 val;
    return rd_reg(RegAddr::CTRL_REG1, &val);
}

int main()
{
    AccelLis2de12 accel;

    return accel.read_test() ? 0 : 1;
}
